==> Stat2Data_1.6.tar.gz: Stat2Data/man/WeightLossIncentive.Rd <==
\name{WeightLossIncentive}
\alias{WeightLossIncentive}
\docType{data}
\title{WeightLossIncentive}
\description{
An experiment to see if financial incentives improve weight loss
}
%\usage{data(WeightLossIncentive)}
\format{
  A dataset with 38 observations on the following 3 variables.
  \tabular{rl}{
    \code{WeightLoss}\tab {Weight loss (in pounds) after four months}\cr
    \code{Group}\tab {Treatment group: \code{Control} or \code{Incentive}}\cr
    \code{Month7Loss}\tab {Weight loss (in pounds) after seven months}\cr
  }
}
\details{
Researchers investigated
whether financial incentives would help people lose weight more successfully. Some participants in
the study were randomly assigned to a treatment group that was offered financial incentives for
achieving weight loss goals, while others were assigned to a control group that did not use financial
incentives. All participants were monitored over a four month period and the net weight change
(Before - After in pounds) at the end of this period was recorded for each individual. Then the
individuals were left alone for three months with a followup weight check at the seven-month mark
to see whether weight losses persisted after the original four months of treatment.\cr
The 4-month data alone (with missing values omitted) is stored in WeightLossIncentive4. \cr
The 7-month data alone (with missing values omitted) is stored in WeightLossIncentive7.
}
\source{
``Financial incentive-based approaches for weight loss," Journal of the American Medical Association by Volpp,
John, Troxel, et. al., Vol. 200, no. 22, pp 2631-2637, (Dec. 2008)
}

\keyword{datasets}

==> Stat2Data_2.0.0.tar.gz: Stat2Data/man/WeightLossIncentive.Rd <==
\name{WeightLossIncentive}
\alias{WeightLossIncentive}
\docType{data}
\title{Do Financial Incentives Improve Weight Loss?}
\description{
An experiment to see if financial incentives improve weight loss
}
\format{
  A dataset with 38 observations on the following 3 variables.
  \tabular{rl}{
    \code{WeightLoss}\tab {Weight loss (in pounds) after four months}\cr
    \code{Group}\tab {Treatment group: \code{Control} or \code{Incentive}}\cr
    \code{Month7Loss}\tab {Weight loss (in pounds) after seven months}\cr
  }
}
\details{
Researchers investigated
whether financial incentives would help people lose weight more successfully. Some participants in
the study were randomly assigned to a treatment group that was offered financial incentives for
achieving weight loss goals, while others were assigned to a control group that did not use financial
incentives. All participants were monitored over a four month period and the net weight change
(Before - After in pounds) at the end of this period was recorded for each individual. Then the
individuals were left alone for three months with a followup weight check at the seven-month mark
to see whether weight losses persisted after the original four months of treatment.\cr
The 4-month data alone (with missing values omitted) is stored in WeightLossIncentive4. \cr
The 7-month data alone (with missing values omitted) is stored in WeightLossIncentive7.
}
\source{
``Financial incentive-based approaches for weight loss," Journal of the American Medical Association by Volpp,
John, Troxel, et. al., Vol. 200, no. 22, pp 2631-2637, (Dec. 2008)
}

\keyword{datasets}
